### Copyright 1999-2015. Parallels IP Holdings GmbH. All Rights Reserved.
import os
import os.path
import sys
from optparse import OptionParser
import logging as log
import plesk_config
import fnmatch
import time

def get_maildir_status(mailddir, now):
    """ Return True, if specified maildir has been changed less then month ago """
    for suffix in ["cur", "new"]:
        d = os.path.join(mailddir, suffix)
        if not os.path.isdir(d):
            return False

        age = now - os.path.getmtime(d)
        log.debug("Mailname %s, age %s", d, age)
        if age <= 30 * 24 * 3600:
            return True

    return False

def do_main():
    parser = OptionParser(usage="Usage: %prog [-v]")
    parser.add_option("-v", "--verbose", action="count", help="Increase verbosity (can be specified multiple times)")
    (options, args) = parser.parse_args()

    log_level = log.WARNING
    if options.verbose == 1:
        log_level = log.INFO
    elif options.verbose >= 2:
        log_level = log.DEBUG

    log.basicConfig(format='%(levelname)s:%(message)s', level=log_level)
    plesk_mailnames_d = plesk_config.get('PLESK_MAILNAMES_D')

    live_mbox_count = 0
    now = time.time()
    if not os.path.isdir(plesk_mailnames_d):
        log.debug("%s is not a directory", plesk_mailnames_d)
        return 0

    for domain in os.listdir(plesk_mailnames_d):
        if not os.path.isdir(os.path.join(plesk_mailnames_d, domain)):
            continue

        if domain == ".spamtrain":
            continue

        log.debug("* domain %s", domain)
        for mailbox in os.listdir(os.path.join(plesk_mailnames_d, domain)):
            if not os.path.isdir(os.path.join(plesk_mailnames_d, domain, mailbox, "Maildir")):
                continue

            log.debug("\tmail %s", mailbox)
            if get_maildir_status(os.path.join(plesk_mailnames_d, domain, mailbox, "Maildir"), now):
                log.debug("+ %s@%s", mailbox, domain)
                live_mbox_count += 1
                continue

            for subfolder in os.listdir(os.path.join(plesk_mailnames_d, domain, mailbox, "Maildir")):
                if not fnmatch.fnmatch(subfolder, '.*'):
                    # Keep only imap subfolders
                    continue

                if subfolder == ".Spam":
                    # Exclude spamtrain folders
                    continue

                if get_maildir_status(os.path.join(plesk_mailnames_d, domain, mailbox, "Maildir", subfolder), now):
                    log.debug("+ %s@%s (%s)", mailbox, domain, subfolder)
                    live_mbox_count += 1
                    break

    return live_mbox_count

def main():
    try:
        count = do_main()
        log.debug("Count %d", count)
        print(count)
    except SystemExit:
        raise
    except Exception as ex:
        log.error('%s', ex)
        log.debug(ex, exc_info=True)
        sys.exit(1)

if __name__ == '__main__':
    main()

# vim: ts=4 sts=4 sw=4 et :
